#
# fishing.R,  8 Jul 23
#
# Data from:
# Characterizing the evolution of statically-detectable performance issues of Android apps
# Teerath Das1, Massimiliano Di Penta, and Ivano Malavolta

library("colorspace")
library("plyr")
library("survival")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(2)


issue_survive=function(df)
{
df_mod=survfit(Surv(df$start_rem, df$ISSUE_STATUS==0) ~ 1)
lines(df_mod, col=df$col_str[1])
}



tapps=read.csv("targetedApps.csv", as.is=TRUE)

# ISSUE_STATUS == 1, when issue is 'alive', i.e., has not been Removed
ip=read.csv("identifiedPerformanceIssues.csv", as.is=TRUE)

ip$start_rem=(ifelse(ip$ISSUE_STATUS==1, ip$END_COMMIT_TIMESTAMP,
				 as.numeric(ip$REMOVAL_COMMIT_TIMESTAMP))-ip$START_COMMIT_TIMESTAMP)/(60*60*24)

# How many Apps contain a given number of issues?
plot(count(count(ip$REPONAME)$freq), log="xy",
	xlab="Issues", ylab="Apps")

app_icnt=count(ip$REPONAME)
app_5cnt=subset(app_icnt, freq >= 5)

# Keep apps containing five or more issues
ip_5=subset(ip, REPONAME %in% app_5cnt$x)

ip_5_mod=survfit(Surv(ip_5$start_rem, ip_5$ISSUE_STATUS==0) ~ 1)

unq_issues=unique(ip_5$ISSUE_TYPE)
pal_col=rainbow(length(unq_issues))
ip_5$col_str=mapvalues(ip_5$ISSUE_TYPE, unq_issues, 1:length(unq_issues))

plot(ip_5_mod, col=pal_col[c(1,2,2)],
	xaxs="i", yaxs="i",
	xlab="Days", ylab="Survival")

d_ply(ip_5, .(ISSUE_TYPE), issue_survive)

plot(ip_5_mod, col=pal_col[c(1,2,2)],
	xaxs="i", yaxs="i",
	xlim=c(0, 220),
	xlab="Days", ylab="Survival")

pal_col=rainbow(2)
plot(ip_5_mod, col=pal_col[c(1,2,2)],
	xaxs="i", yaxs="i",
	xlab="Days", ylab="Survival")

dev.copy(dev=png, file="performance-refact.png")
dev.off()

app5=merge(ip_5, tapps, by.x="REPONAME", by.y="RepositoryGitHubName", all.x=TRUE)

app5_cox=coxph(Surv(app5$start_rem, ip_5$ISSUE_STATUS==0) ~ factor(app5$ISSUE_TYPE)+factor(app5$Install)+app5$Contributors)
summary(app5_cox)


